@@ -1,4 +1,5 @@
 #include "config.h"
+#include "acconf.h"
 #include "option.h"
 #include "quotes.h"
 #include "walk.h"
@@ -28,8 +29,8 @@ config_t::config_t()
   pricing_leeway     = 24 * 3600;
   budget_flags       = BUDGET_NO_BUDGET;
   balance_format     = "%20T  %2_%-a\n";
-  register_format    = ("%D %-.20P %-.22A %12.66t %12.80T\n%/"
-			"%32|%-.22A %12.66t %12.80T\n");
+  register_format    = ("%D %-.20P %-.22A %12.67t %12.80T\n%/"
+			"%32|%-.22A %12.67t %12.80T\n");
   wide_register_format = ("%D  %-.35P %-.38A %22.108t %22.132T\n%/"
 			  "%48|%-.38A %22.108t %22.132T\n");
   plot_amount_format = "%D %(St)\n";
@@ -202,7 +203,7 @@ void config_t::process_options(const std::string&     command,
     else if (command == "E") {
       display_predicate = "t";
     }
-    else if (command == "r") {
+    else if (command == "r" && ! show_empty) {
       display_predicate = "a";
     }
   }
@@ -342,7 +343,7 @@ void parse_ledger_data(journal_t * journal, parser_t * cache_parser,
   }
 
   if (entry_count == 0)
-    throw error("Please specify ledger file using -f,"
+    throw error("Please specify ledger file using -f"
 		" or LEDGER_FILE environment variable.");
 
   VALIDATE(journal->valid());
@@ -351,12 +352,20 @@ void parse_ledger_data(journal_t * journal, parser_t * cache_parser,
 static void show_version(std::ostream& out)
 {
   out << "Ledger " << ledger::version << ", the command-line accounting tool";
-#ifdef USE_BOOST_PYTHON
-  out << " (Python support enabled)";
-#endif
-  out << "\n\nCopyright (c) 2003-2004, John Wiegley.  All rights reserved.\n\n\
+  out << "\n\nCopyright (c) 2003-2005, John Wiegley.  All rights reserved.\n\n\
 This program is made available under the terms of the BSD Public License.\n\
 See LICENSE file included with the distribution for details and disclaimer.\n";
+  out << "\n(modules: gmp, pcre";
+#ifdef USE_BOOST_PYTHON
+  out << ", python";
+#endif
+#ifdef HAVE_XMLPARSE
+  out << ", xml";
+#endif
+#ifdef HAVE_LIBOFX
+  out << ", ofx";
+#endif
+  out << ")\n";
 }
 
 void option_full_help(std::ostream& out)
@@ -774,11 +783,11 @@ OPT_BEGIN(period, "p:") {
   char buf[32];
   interval_t interval(config.report_period);
   if (interval.begin) {
-    std::strftime(buf, 31, "%Y/%m/%d", std::gmtime(&interval.begin));
+    std::strftime(buf, 31, "%Y/%m/%d", std::localtime(&interval.begin));
     process_option(config_options, "begin", buf);
   }
   if (interval.end) {
-    std::strftime(buf, 31, "%Y/%m/%d", std::gmtime(&interval.end));
+    std::strftime(buf, 31, "%Y/%m/%d", std::localtime(&interval.end));
     process_option(config_options, "end", buf);
   }
 } OPT_END(period);
