@@ -36,6 +36,7 @@ namespace ledger {
 
 static std::string  path;
 static unsigned int linenum;
+static accounts_map account_aliases;
 
 #ifdef TIMELOG_SUPPORT
 static std::time_t time_in;
@@ -161,7 +162,13 @@ transaction_t * parse_transaction(char * line, account_t * account)
     *e = '\0';
   }
 
-  xact->account = account->find_account(p);
+  if (account_aliases.size() > 0) {
+    accounts_map::const_iterator i = account_aliases.find(p);
+    if (i != account_aliases.end())
+      xact->account = (*i).second;
+  }
+  if (! xact->account)
+    xact->account = account->find_account(p);
 
   return xact.release();
 }
@@ -304,6 +311,50 @@ static inline void parse_symbol(char *& p, std::string& symbol)
     throw parse_error(path, linenum, "Failed to parse commodity");
 }
 
+bool textual_parser_t::test(std::istream& in) const
+{
+  char buf[5];
+
+  in.read(buf, 5);
+  if (std::strncmp(buf, "<?xml", 5) == 0) {
+#ifdef HAVE_XMLPARSE
+    throw parse_error(path, linenum, "Ledger file contains XML data, but format was not recognized");
+#else
+    throw parse_error(path, linenum, "Ledger file contains XML data, but no XML support present");
+#endif
+  }
+
+  in.seekg(0, std::ios::beg);
+  assert(in.good());
+  return true;
+}
+
+static void clock_out_from_timelog(const std::time_t when,
+				   journal_t * journal)
+{
+  std::auto_ptr<entry_t> curr(new entry_t);
+  curr->date  = when;
+  curr->state = entry_t::CLEARED;
+  curr->code  = "";
+  curr->payee = last_desc;
+
+  double diff = std::difftime(curr->date, time_in);
+  char   buf[32];
+  std::sprintf(buf, "%lds", long(diff));
+  amount_t amt;
+  amt.parse(buf);
+
+  transaction_t * xact
+    = new transaction_t(last_account, amt, TRANSACTION_VIRTUAL);
+  curr->add_transaction(xact);
+
+  if (! journal->add_entry(curr.get()))
+    throw parse_error(path, linenum,
+		      "Failed to record 'out' timelog entry");
+  else
+    curr.release();
+}
+
 unsigned int textual_parser_t::parse(std::istream&	 in,
 				     journal_t *	 journal,
 				     account_t *	 master,
@@ -379,28 +430,7 @@ unsigned int textual_parser_t::parse(std::istream&	 in,
 
 	  struct std::tm when;
 	  if (strptime(date.c_str(), "%Y/%m/%d %H:%M:%S", &when)) {
-	    std::auto_ptr<entry_t> curr(new entry_t);
-	    curr->date  = std::mktime(&when);
-	    curr->state = entry_t::CLEARED;
-	    curr->code  = "";
-	    curr->payee = last_desc;
-
-	    double diff = std::difftime(curr->date, time_in);
-	    char   buf[32];
-	    std::sprintf(buf, "%lds", long(diff));
-	    amount_t amt;
-	    amt.parse(buf);
-
-	    transaction_t * xact
-	      = new transaction_t(last_account, amt, TRANSACTION_VIRTUAL);
-	    curr->add_transaction(xact);
-
-	    if (! journal->add_entry(curr.get()))
-	      throw parse_error(path, linenum,
-				"Failed to record 'out' timelog entry");
-	    else
-	      curr.release();
-
+	    clock_out_from_timelog(std::mktime(&when), journal);
 	    count++;
 	  } else {
 	    throw parse_error(path, linenum, "Cannot parse timelog entry date");
@@ -569,6 +599,25 @@ unsigned int textual_parser_t::parse(std::istream&	 in,
 	  python_eval(in, PY_EVAL_MULTI);
 	}
 #endif
+	else if (word == "alias") {
+	  char * b = skip_ws(p);
+	  if (char * e = std::strchr(b, '=')) {
+	    char * z = e - 1;
+	    while (std::isspace(*z))
+	      *z-- = '\0';
+	    *e++ = '\0';
+	    e = skip_ws(e);
+
+	    // Once we have an alias name (b) and the target account
+	    // name (e), add a reference to the account in the
+	    // `account_aliases' map, which is used by the transaction
+	    // parser to resolve alias references.
+	    account_t * acct = account_stack.front()->find_account(e);
+	    std::pair<accounts_map::iterator, bool> result
+	      = account_aliases.insert(accounts_pair(b, acct));
+	    assert(result.second);
+	  }
+	}
 	break;
       }
 
@@ -611,6 +660,11 @@ unsigned int textual_parser_t::parse(std::istream&	 in,
   }
 
  done:
+  if (last_account) {
+    clock_out_from_timelog(now, journal);
+    last_account = NULL;
+  }
+
   if (added_auto_entry_hook)
     journal->remove_entry_finalizer(&auto_entry_finalizer);
 
